#!/usr/bin/env python
# coding: utf-8

# In[3]:


from distutils.core import setup
f = setup(
  name = 'matrice_math',         
  packages = ['matrice_math'],  
  version = '0.1.1',      
  license='MIT',       
  description = 'Matrice_math is package that can be used for matrix and determinant computing with Python',   
  author = 'Ishaan Sawant',                   
  author_email = 'imsawant05@gmail.com',      
  url = 'https://github.com/KAMEHAMEHA-05/matrice_math',   
  download_url = 'https://github.com/KAMEHAMEHA-05/matrice_math/archive/refs/tags/v_01.tar.gz',    
  keywords = ['matrix', 'determinants', 'matrices', 'array'],   
  install_requires=[],           
  classifiers=['Development Status :: 4 - Beta','Intended Audience :: Developers', 'Topic :: Software Development :: Build Tools','License :: OSI Approved :: MIT License',   'Programming Language :: Python :: 3','Programming Language :: Python :: 3.4','Programming Language :: Python :: 3.5','Programming Language :: Python :: 3.6','Programming Language :: Python :: 3.7']
)


# In[ ]:




